@@ -6,7 +6,7 @@ use 5.008001;
 use Carp qw( croak );
 
 # ABSTRACT: Write Perl bindings to non-Perl libraries with FFI. No XS required.
-our $VERSION = '0.37_02'; # TRIAL VERSION
+our $VERSION = '0.37_03'; # TRIAL VERSION
 
 # Platypus Man,
 # Platypus Man,
@@ -524,7 +524,7 @@ sub _have_pm
 
 package FFI::Platypus::Function;
 
-our $VERSION = '0.37_02'; # TRIAL VERSION
+our $VERSION = '0.37_03'; # TRIAL VERSION
 
 use overload '&{}' => sub {
   my $ffi = shift;
@@ -545,7 +545,7 @@ use overload '&{}' => sub {
   sub { $self->{code}->(@_) };
 };
 
-our $VERSION = '0.37_02'; # TRIAL VERSION
+our $VERSION = '0.37_03'; # TRIAL VERSION
 
 sub new
 {
@@ -574,13 +574,13 @@ sub get_data
 
 package FFI::Platypus::ClosureData;
 
-our $VERSION = '0.37_02'; # TRIAL VERSION
+our $VERSION = '0.37_03'; # TRIAL VERSION
 
 package FFI::Platypus::Type;
 
 use Carp qw( croak );
 
-our $VERSION = '0.37_02'; # TRIAL VERSION
+our $VERSION = '0.37_03'; # TRIAL VERSION
 
 sub new
 {
@@ -674,7 +674,7 @@ FFI::Platypus - Write Perl bindings to non-Perl libraries with FFI. No XS requir
 
 =head1 VERSION
 
-version 0.37_02
+version 0.37_03
 
 =head1 SYNOPSIS
 
@@ -2152,9 +2152,8 @@ Documentation and tools for using Platypus with the Assembly
 
 =item L<Convert::Binary::C>
 
-An interface for interacting with C C<struct> types.  Unfortunately it 
-appears to be unmaintained, and has a failing pod test, so I cannot 
-recommend it for use by CPAN modules.
+A great interface for decoding C data structures, including C<struct>s,
+C<enum>s, C<#define>s and more.
 
 =item L<pack and unpack|perlpacktut>
 
